# pykmtronic

[![PyPI version](https://badge.fury.io/py/pykmtronic.svg)](https://badge.fury.io/py/pykmtronic)

This library provides a Python3 interface to [KM-Tronic web relays](https://info.kmtronic.com/lan-relays.html).

# Tested equipments:

- https://info.kmtronic.com/manuals/user_manuals/W2CR_WEB_TWO_CHANNEL_RELAY.pdf
